"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.toContainValue = void 0;
const utils_1 = require("../utils/utils");
/**
 * Use `toContainValue` function when you want to check that an element's value contains the expected string or substring
 *
 * @example
 * ```typescript
 * // could be used with Promise<ElementHandle>
 * await expect(page.$('input')).toContainValue('A123');
 *
 * // or with ElementHandle
 * const toastElement = await page.$('input);
 * await expect(toastElement).toContainValue('A123');
 *
 * // or using an array of page and selector
 * await expect([page, 'input']).toContainValue('A123');
 *
 * // also you can check value ignoring case sensitive
 * await expect(page.$('input')).toContainValue('a123', {ignoreCase: true})
 * ```
 *
 * @param this
 * @param element
 * @param expectedValue
 * @param options
 * @returns
 */
async function toContainValue(element, expectedValue, options) {
    try {
        const elementHandle = utils_1.getElementHandle(element, options === null || options === void 0 ? void 0 : options.waitForState);
        let actualValue = await utils_1.getValue(elementHandle);
        if (options === null || options === void 0 ? void 0 : options.ignoreCase) {
            actualValue = utils_1.formatText(actualValue, { ignoreCase: true });
            expectedValue = utils_1.formatText(expectedValue, { ignoreCase: true });
        }
        else if (options === null || options === void 0 ? void 0 : options.trim) {
            actualValue = utils_1.formatText(actualValue, { trim: true });
        }
        return {
            pass: actualValue.includes(expectedValue),
            message: () => utils_1.getErrorMessage(this, 'toContainValue', expectedValue, actualValue),
        };
    }
    catch (error) {
        return {
            pass: false,
            // eslint-disable-next-line @typescript-eslint/ban-ts-comment
            // @ts-ignore
            message: () => error.toString(),
        };
    }
}
exports.toContainValue = toContainValue;
